"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = require("assert");
const cross_fetch_1 = __importDefault(require("cross-fetch"));
const misc_utils_of_mine_generic_1 = require("misc-utils-of-mine-generic");
const imageCreation_1 = require("./browser/imageCreation");
const format_1 = require("./format");
const base64_1 = require("./util/base64");
const fileUtil_1 = require("./util/fileUtil");
const imageUtil_1 = require("./util/imageUtil");
const fileType = require("file-type");
/**
 * A thin layer on top of cv.Mat with lots of utilities to load, write, encode, etc.
 */
class File {
    constructor(name, _mat) {
        this.name = name;
        this._mat = _mat;
    }
    size() {
        return {
            width: this._mat.cols,
            height: this._mat.rows
        };
    }
    getMimeType() {
        return misc_utils_of_mine_generic_1.getMimeTypeForExtension(this.getExtension());
    }
    getExtension() {
        return misc_utils_of_mine_generic_1.getFileExtension(this.name).toLowerCase();
    }
    asMat() {
        return this._mat;
    }
    asImageData() {
        return imageUtil_1.toImageData(this._mat);
    }
    asHTMLImageData() {
        return imageCreation_1.asHtmlImageData(this._mat);
    }
    asDataUrl() {
        return 'data:' + this.getMimeType() + ';' + this.name + ';base64,' + this.asBase64();
    }
    get width() {
        return this._mat.cols;
    }
    get height() {
        return this._mat.rows;
    }
    get mat() {
        return this._mat;
    }
    /**
     * It removes the the file from file system and also delete() this file's Mat
     */
    remove(deleteMat = true) {
        deleteMat && this.delete();
        this.name && fileUtil_1.isFile(this.name) && fileUtil_1.removeFile(this.name);
        return this;
    }
    /**
     * Returns an array buffer containing the image encoded in given format or inferring format from its name.
     */
    asArrayBuffer(format = this.getExtension()) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield format_1.encodeOrThrow(this.asImageData(), format);
        });
    }
    /**
     * Writes this image on given file path, encoded in given format (or inferred form current name).
     */
    write(path = this.name, format = this.getExtension()) {
        return __awaiter(this, void 0, void 0, function* () {
            const a = yield this.asArrayBuffer(format);
            fileUtil_1.writeFile(path, new Uint8ClampedArray(a));
            return this;
        });
    }
    setMat(mat) {
        this.delete();
        this._mat = mat;
        return this;
    }
    /**
     * Shows this image in given HTML canvas or image element.
     */
    show(el) {
        cv.imshow(el, this.asMat());
        return this;
    }
    asBase64(format = this.getExtension()) {
        return __awaiter(this, void 0, void 0, function* () {
            var encoded = yield this.asArrayBuffer(format);
            return base64_1.arrayBufferToBase64(encoded);
        });
    }
    delete() {
        try {
            this._mat && this._mat.delete();
        }
        catch (error) {
        }
    }
    /**
     * Converts the Mat of this file to RGBA channel type. It will replace the current mat and delete the original.
     */
    toRgba() {
        const dst = imageUtil_1.toRgba(this.mat);
        this.mat.delete();
        this._mat = dst;
        return this;
    }
    clone(name = this.name) {
        return File.fromMat(this.mat.clone(), name);
    }
    /**
     * Loads file from given base64 string containing an encoded image.
    */
    static fromBase64(base64, name) {
        var buffer = Buffer.from(Base64.decode(base64), 'base64');
        return File.fromArrayBuffer(buffer, name || File.getBufferFileName(buffer));
    }
    /**
     * Loads file from given array buffer containing an encoded image.
     */
    static fromArrayBuffer(buffer, name) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                name = name || File.getBufferFileName(buffer);
                const format = misc_utils_of_mine_generic_1.getFileExtension(name);
                var data = yield format_1.decodeOrThrow(buffer, format);
                return File.fromData(data, name);
            }
            catch (error) {
                console.error(error);
                throw error;
            }
        });
    }
    /**
     * Loads file from given array buffer view containing an encoded image.
     */
    static fromArrayBufferView(a, name) {
        return __awaiter(this, void 0, void 0, function* () {
            return File.fromArrayBuffer(a.buffer, name);
        });
    }
    static getBufferFileType(a) {
        var t = fileType(a);
        if (!t) {
            throw new Error('Could not get file type for buffer');
        }
        return t;
    }
    static getBufferFileName(a) {
        var t = File.getBufferFileType(a);
        return misc_utils_of_mine_generic_1.unique('file') + t.ext;
    }
    /**
     * Loads file from given data url string containing an encoded image.
    */
    static fromDataUrl(dataUrl, name) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield File.fromBase64(base64_1.urlToBase64(dataUrl), name);
        });
    }
    /**
     * Loads files from files in html input element of type "file".
     */
    static fromHtmlFileInputElement(el) {
        if (!misc_utils_of_mine_generic_1.inBrowser()) {
            throw new Error('This method is only supported in the browser');
        }
        return Promise.all(Array.from(el.files).map(file => new Promise((resolve, reject) => {
            var reader = new FileReader();
            reader.addEventListener('loadend', (e) => __awaiter(this, void 0, void 0, function* () { return resolve(yield File.fromArrayBuffer(reader.result, file.name)); }));
            reader.readAsArrayBuffer(file);
        })));
    }
    /**
     * Loads file form existing HTMLElement or HTMLImageElement
     */
    static fromCanvas(el) {
        if (!misc_utils_of_mine_generic_1.inBrowser()) {
            throw new Error('This method is only supported in the browser');
        }
        return File.fromMat(cv.imread(el));
    }
    /**
     * Shortcut for [resolve] that returns the first result.
     */
    static resolveOne(files) {
        return __awaiter(this, void 0, void 0, function* () {
            var a = yield File.resolve(files);
            return a.length > 0 ? a[0] : undefined;
        });
    }
    /**
     * Given paths, urls or files it will try to load them all and return a list of File for those succeed.
     */
    static resolve(files) {
        return __awaiter(this, void 0, void 0, function* () {
            var a = misc_utils_of_mine_generic_1.asArray(files || []).filter(misc_utils_of_mine_generic_1.notUndefined);
            var result = yield misc_utils_of_mine_generic_1.serial(a.map(f => () => __awaiter(this, void 0, void 0, function* () {
                if (typeof f === 'string') {
                    if (fileUtil_1.isFile(f)) {
                        return yield File.fromFile(f);
                    }
                    else {
                        return yield File.fromUrl(f);
                    }
                }
                else {
                    assert_1.ok(ArrayBuffer.isView(f._mat.data.buffer));
                    return f;
                }
            })));
            return result.filter(misc_utils_of_mine_generic_1.notUndefined);
        });
    }
    static isFile(f) {
        return !!f && !!f.name && !!f._mat && !!f._mat.data &&
            typeof f.constructor !== 'undefined' && !!f.asImageData && !!f.asMat;
    }
    static asPath(f) {
        return typeof f === 'string' ? f : f.name;
    }
    static fromData(data, name) {
        return new File(File._buildName(name), cv.matFromImageData(data));
    }
    static _buildName(name) {
        return name || misc_utils_of_mine_generic_1.unique('file') + '.png';
    }
    static fromMat(mat, name) {
        return new File(File._buildName(name), mat);
    }
    toString() {
        return `[File "${this.name}"]`;
    }
    static fromUrl(url, o = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const p = format_1.getDefaultCodec();
            const response = yield cross_fetch_1.default(url);
            const buffer = yield response.arrayBuffer();
            var data = yield format_1.decodeOrThrow(buffer);
            return File.fromData(data, o.name || misc_utils_of_mine_generic_1.getFileNameFromUrl(url));
        });
    }
    static fromFile(path, name = misc_utils_of_mine_generic_1.basename(path)) {
        return __awaiter(this, void 0, void 0, function* () {
            const data = yield format_1.decodeOrThrow(fileUtil_1.readFile(path).buffer);
            return File.fromData(data, name);
        });
    }
}
exports.File = File;
//# sourceMappingURL=file.js.map