"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const File_1 = require("../File");
/**
 * Creates an CV ImageData object from given image.
 */
function toImageData(img) {
    return {
        data: new Uint8ClampedArray(img.data),
        width: img.cols,
        height: img.rows
    };
}
exports.toImageData = toImageData;
exports.asImageData = toImageData;
function isMat(m) {
    return m && typeof m.rows === 'number' && typeof m.cols === 'number' && typeof m.data === 'object' && typeof m.copyTo === 'function';
}
exports.isMat = isMat;
/**
 * Returns a new image that is identical to given (1, 3 or 4 channels) but has 4 RGBA channels.
 */
function toRgba(mat, dst = new cv.Mat()) {
    const depth = mat.type() % 8;
    const scale = depth <= cv.CV_8S ? 1.0 : (depth <= cv.CV_32S ? 1.0 / 256.0 : 255.0);
    const shift = (depth === cv.CV_8S || depth === cv.CV_16S) ? 128.0 : 0.0;
    mat.convertTo(dst, cv.CV_8U, scale, shift);
    switch (dst.type()) {
        case cv.CV_8UC1:
            cv.cvtColor(dst, dst, cv.COLOR_GRAY2RGBA);
            break;
        case cv.CV_8UC3:
            cv.cvtColor(dst, dst, cv.COLOR_RGB2RGBA);
            break;
        case cv.CV_8UC4:
            break;
        default:
            throw new Error('Bad number of channels (Source image must have 1, 3 or 4 channels)');
    }
    return dst;
}
exports.toRgba = toRgba;
function fromFile(f) {
    return __awaiter(this, void 0, void 0, function* () {
        const file = yield File_1.File.fromFile(f);
        return file.asMat();
    });
}
exports.fromFile = fromFile;
function fromArrayBuffer(a) {
    return __awaiter(this, void 0, void 0, function* () {
        const file = yield File_1.File.fromArrayBuffer(a);
        return file.asMat();
    });
}
exports.fromArrayBuffer = fromArrayBuffer;
function fromUrl(f) {
    return __awaiter(this, void 0, void 0, function* () {
        const file = yield File_1.File.fromUrl(f);
        return file.asMat();
    });
}
exports.fromUrl = fromUrl;
/**
 * Compare two images by getting the L2 error (square-root of sum of squared error). The lower the result the more similar are the images.
 */
function compareL2(f1, f2, destroyBoth = false) {
    const a = asMat(f1), b = asMat(f2);
    if (a.rows > 0 && a.rows == b.rows && a.cols > 0 && a.cols == a.cols) {
        // Calculate the L2 relative error between images.
        const errorL2 = cv.norm1(a, b, cv.NORM_L2);
        // Convert to a reasonable scale, since L2 error is summed across all pixels of the image.
        const similarity = errorL2 / (a.rows * a.cols);
        destroyBoth && del(a, b);
        return similarity;
    }
    else {
        //Images have a different size
        return 1.0;
    }
}
exports.compareL2 = compareL2;
function asMat(f) {
    return File_1.File.isFile(f) ? f.asMat() : f;
}
exports.asMat = asMat;
function del(...m) {
    m.forEach(m => m.delete());
}
exports.del = del;
/**
 * sets the color of pixel at coords (x,y)
 */
function set(m, x, y, val) {
    const c = m.channels();
    let view = m.data;
    for (let i = 0; i < val.length; i++) {
        view[y * c * m.cols + x * c + i] = val[i];
    }
}
exports.set = set;
/**
 * gets the color of pixel at coords (x,y)
 */
function get(m, x, y) {
    const c = m.channels();
    let view = m.data;
    const v = [];
    for (let i = 0; i < c; i++) {
        v.push(view[y * c * m.cols + x * c + i]);
    }
    return v;
}
exports.get = get;
function map(mat, dst, fn) {
    for (let y = 0; y < mat.rows; y++) {
        for (let x = 0; x < mat.cols; x++) {
            const v = fn(get(mat, x, y), x, y);
            set(dst, x, y, v);
        }
    }
}
exports.map = map;
let _noArray;
/**
 * for overload methods that won't accept undefined as argument, like 'mask' cv.add()
 */
function noArray() {
    if (!_noArray) {
        _noArray = cv.Mat.ones(0, 0, cv.CV_8U);
    }
    return _noArray;
}
exports.noArray = noArray;
//# sourceMappingURL=imageUtil.js.map